From a684b5dd2d760041b727c19f83b14b85276f09bc Mon Sep 17 00:00:00 2001
From: Toshikazu Nakayama <nakayama.ts@ncos.nec.co.jp>
Date: Tue, 18 Jan 2011 15:31:40 +0900
Subject: [PATCH 3/3] load_module_symbols_helper().

load_module_symbols_helper("module name") which load module symbols.
Usage is little easier than load_module_symbols().

Add CRASH_MODULE_PATH environment.
This env is evaluated in module_objfile_search().
That way, the non-standard CRASH_MODULE_PATH could be used by the "mod"
command as well.

Signed-off-by: Toshikazu Nakayama <nakayama.ts@ncos.nec.co.jp>
---
 crash-5.1.1/defs.h   |    1 +
 crash-5.1.1/kernel.c |   31 +++++++++++++++++++++++++++++++
 2 files changed, 32 insertions(+), 0 deletions(-)

diff --git a/crash-5.1.1/defs.h b/crash-5.1.1/defs.h
index 1f83094..7fc8c92 100755
--- a/crash-5.1.1/defs.h
+++ b/crash-5.1.1/defs.h
@@ -3940,6 +3940,7 @@ void verify_version(void);
 void verify_spinlock(void);
 void non_matching_kernel(void);
 struct load_module *modref_to_load_module(char *);
+int load_module_symbols_helper(char *);
 void unlink_module(struct load_module *);
 int check_specified_module_tree(char *, char *);
 int is_system_call(char *, ulong);
diff --git a/crash-5.1.1/kernel.c b/crash-5.1.1/kernel.c
index c2b8b51..84e251c 100755
--- a/crash-5.1.1/kernel.c
+++ b/crash-5.1.1/kernel.c
@@ -3439,6 +3439,7 @@ module_objfile_search(char *modref, char *filename, char *tree)
 	int initrd;
 	struct syment *sp;
 	char *p1, *p2;
+	char *env;
 
 	retbuf = NULL;
 	initrd = FALSE;
@@ -3553,6 +3554,18 @@ module_objfile_search(char *modref, char *filename, char *tree)
 		kt->utsname.release);
 	retbuf = search_directory_tree(dir, file, 0);
 
+	if (!retbuf && (env = getenv("CRASH_MODULE_PATH"))) {
+		sprintf(dir, "%s", env);
+		if (!(retbuf = search_directory_tree(dir, file, 0))) {
+			switch (kt->flags & (KMOD_V1|KMOD_V2))
+			{
+			case KMOD_V2:
+				sprintf(file, "%s.ko", modref);
+				retbuf = search_directory_tree(dir, file, 0);
+			}
+		}
+	}
+
 	if (!retbuf) {
 		sprintf(dir, "/lib/modules/%s/updates", kt->utsname.release);
 		if (!(retbuf = search_directory_tree(dir, file, 0))) {
@@ -3625,6 +3638,24 @@ find_module_objfile(char *modref, char *filename, char *tree)
 }
 
 /*
+ * Try to load module symbols with name.
+ */
+int
+load_module_symbols_helper(char *name)
+{
+	char *objfile;
+	ulong address;
+
+	if (is_module_name(name, &address, NULL) &&
+		(objfile = find_module_objfile(name, NULL, NULL))) {
+		do_module_cmd(LOAD_SPECIFIED_MODULE_SYMBOLS, name, address,
+				objfile, NULL);
+		return TRUE;
+	}
+	return FALSE;
+}
+
+/*
  *  Unlink any temporary remote module object files.
  */
 void
-- 
1.7.4.rc2.3.g60a2e

